@@ -3,6 +3,14 @@ from __future__ import print_function
 import os
 import subprocess
 import stretch_body.hello_utils as hu
+
+
+
+import argparse
+parser=argparse.ArgumentParser(description='Echo the robot and computer hardware details to the console')
+args=parser.parse_args()
+
+
 hu.print_stretch_re_use()
 
 print('Versions')
@@ -25,12 +33,12 @@ l=lift.Lift()
 l.startup(threaded=False)
 print('Version: stretch_body: %s'%stretch_body.__version__)
 print('---------- Boards ----------')
-print('Pimu:            %s'%p.board_info['board_version'])
-print('Wacc:            %s'%w.board_info['board_version'])
-print('Left wheel:      %s' %b.left_wheel.board_info['board_version'])
-print('Right wheel:     %s' %b.right_wheel.board_info['board_version'])
-print('Lift stepper:    %s' %l.motor.board_info['board_version'])
-print('Arm stepper:     %s' %a.motor.board_info['board_version'])
+print('Pimu:            %s'%p.board_info['board_variant'])
+print('Wacc:            %s'%w.board_info['board_variant'])
+print('Left wheel:      %s' %b.left_wheel.board_info['board_variant'])
+print('Right wheel:     %s' %b.right_wheel.board_info['board_variant'])
+print('Lift stepper:    %s' %l.motor.board_info['board_variant'])
+print('Arm stepper:     %s' %a.motor.board_info['board_variant'])
 print('---------- Firmware ----------')
 print('Pimu:            %s'%p.board_info['firmware_version'])
 print('Wacc:            %s'%w.board_info['firmware_version'])
